<?php
class ConnectionManager
{
	/**
	 * Cached Connection objects
	 * @type Array
	 */
	protected $cache = array();

	/**
	 * Project connections data
	 * @type Array
	 */
	protected $_connectionsData;

	/**
	 * Project connections data
	 * @type Array
	 */
	protected $_connectionsIdByName = array();

	
	/**
	 * An array storing the correspondence between project
	 * datasource tables names and connections ids
	 * @type Array
	 */	
	protected $_tablesConnectionIds;
	
	
	/**
	 * @constructor
	 */
	function ConnectionManager()
	{
		$this->_setConnectionsData();
		$this->_setTablesConnectionIds();
	}
	
	/**
	 * Get connection object by the table name
	 * @param String tName
	 * @return Connection
	 */
	public function byTable( $tName )
	{
		$connId = $this->_tablesConnectionIds[ $tName ];
		if( !$connId )
			return $this->getDefault();
		return $this->byId( $connId );
	}

	/**
	 * Get connection object by the connection name
	 * @param String connName
	 * @return Connection
	 */	
	public function byName( $connName )
	{
		$connId = $this->getIdByName( $connName );
		if( !$connId )
			return $this->getDefault();
		return $this->byId( $connId );
	}
	
	/**
	 * Get connection id by the connection name
	 * @param String connName
	 * @return String
	 */	
	protected function getIdByName( $connName )
	{
		return $this->_connectionsIdByName[ $connName ];
	}
	
	/**
	 * Get connection object by the connection id 
	 * @param String connId
	 * @return Connection
	 */	
	public function byId( $connId )
	{
		if( !isset( $this->cache[ $connId ] ) )
			$this->cache[ $connId ] = $this->getConnection( $connId );

		return $this->cache[ $connId ];
	}
	
	/**
	 * Get the default db connection class
	 * @return Connection
	 */
	public function getDefault()
	{
		return $this->byId( "Tables" );
	}

	/**
	 * Get the users table db connection 
	 * @return Connection
	 */	
	public function getForLogin()
	{
		return $this->byId( "Tables" );
	}
	
	/**
	 * Get the log table db connection 
	 * @return Connection
	 */	
	public function getForAudit()
	{
		return $this->byId( "Tables" );
	}
	
	/**
	 * Get the locking table db connection 
	 * @return Connection
	 */		
	public function getForLocking()
	{
		return $this->getDefault();
	}	
	
	/**
	 * Get the 'ug_groups' table db connection 
	 * @return Connection
	 */	
	public function getForUserGroups()
	{
		return $this->byId( "Tables" );
	}		

	/**
	 * Get the saved searches table db connection 
	 * @return Connection
	 */	
	public function getForSavedSearches()
	{
		return $this->getDefault();
	}

	/**
	 * Get the webreports tables db connection 
	 * @return Connection
	 */		
	public function getForWebReports()
	{
		return $this->getDefault();
	}
	
	/**
	 * @param String connId
	 * @return Connection
	 */
	protected function getConnection( $connId )
	{
		include_once getabspath("connections/Connection.php");
		
		$data = $this->_connectionsData[ $connId ];	
		switch( $data["connStringType"] )
		{
			case "mysql":
				if( useMySQLiLib() )
				{
					include_once getabspath("connections/MySQLiConnection.php");
					return new MySQLiConnection( $data );
				}
				
				include_once getabspath("connections/MySQLConnection.php");	
				return new MySQLConnection( $data );	

			case "mssql":
			case "compact":
				if( useMSSQLWinConnect() )
				{
					include_once getabspath("connections/MSSQLWinConnection.php");
					return new MSSQLWinConnection( $data );
				}
				if( isSqlsrvExtLoaded() )
				{
					include_once getabspath("connections/MSSQLSrvConnection.php");	
					return new MSSQLSrvConnection( $data );
				}
				
				include_once getabspath("connections/MSSQLUnixConnection.php");
				return new MSSQLUnixConnection( $data );			

			case "msaccess":
			case "odbc":
			case "odbcdsn":
			case "custom":
			case "file":
				if( stripos($data["ODBCString"], 'Provider=') !== false )
				{
					include_once getabspath("connections/ADOConnection.php");
					return new ADOConnection( $data );
				}
				
				include_once getabspath("connections/ODBCConnection.php");
				return new ODBCConnection( $data );
			
			case "oracle":
				include_once getabspath("connections/OracleConnection.php");
				return new OracleConnection( $data );

			case "postgre":
				include_once getabspath("connections/PostgreConnection.php");
				return new PostgreConnection( $data );

			case "db2":
				include_once getabspath("connections/DB2Connection.php");
				return new DB2Connection( $data );

			case "informix":
				include_once getabspath("connections/InformixConnection.php");
				return new InformixConnection( $data );

			case "sqlite":
				include_once getabspath("connections/SQLite3Connection.php");
				return new SQLite3Connection( $data );
		}
	}
	
	/**
	 * Set the data representing the project's 
	 * db connection properties
	 */	 
	protected function _setConnectionsData()
	{
		// content of this function can be modified on demo account
		// variable names $data and $connectionsData are important

		$connectionsData = array();
		
		$data = array();
		$data["dbType"] = 0;
		$data["connId"] = "Tables";
		$data["connName"] = "skyfreightv3 at localhost";
		$data["connStringType"] = "mysql";
		$data["connectionString"] = "mysql;localhost;root;;;skyfreightv3;;1"; //currently unused
		
		$this->_connectionsIdByName["skyfreightv3 at localhost"] = "Tables";
		
		$data["connInfo"] = array();
		$data["ODBCUID"] = "root";
		$data["ODBCPWD"] = "";
		$data["leftWrap"] = "`";
		$data["rightWrap"] = "`";
		
		$data["DBPath"] = "db"; //currently unused	
		$data["useServerMapPath"] = 1; //currently unused
		
$host="192.168.1.224";
$user="root";
$pwd="birdistheword978234";
$port="";
//$sys_dbname="erp_cake2go3";

$sys_dbname="skyfreightv3";
 
$_SESSION["dbname"] =$sys_dbname . "?characterEncoding=utf8";

$_SESSION["path"] = "http://192.168.1.243:8080/birt/";


date_default_timezone_set('Asia/Singapore');
$data["connInfo"][0] = $host;
$data["connInfo"][1] = $user;
$data["connInfo"][2] = $pwd;
$data["connInfo"][3] = $port;
$data["connInfo"][4] = $sys_dbname;
;
		$connectionsData["Tables"] = $data;
		$this->_connectionsData = $connectionsData;
	}
	
	/**
	 * Set the data representing the correspondence between 
	 * the project's table names and db connections
	 */	 
	protected function _setTablesConnectionIds()
	{
		$connectionsIds = array();
		$connectionsIds["business_partner"] = "Tables";
		$connectionsIds["item"] = "Tables";
		$connectionsIds["credit_terms"] = "Tables";
		$connectionsIds["shipping_terms"] = "Tables";
		$connectionsIds["cash_receipt"] = "Tables";
		$connectionsIds["purchase"] = "Tables";
		$connectionsIds["cash_disbursment"] = "Tables";
		$connectionsIds["general_journal"] = "Tables";
		$connectionsIds["report_center"] = "Tables";
		$connectionsIds["Sales Report"] = "Tables";
		$connectionsIds["Disbursement Reports"] = "Tables";
		$connectionsIds["Financial Reports"] = "Tables";
		$connectionsIds["Purchase Reports"] = "Tables";
		$connectionsIds["Receivable Reports"] = "Tables";
		$connectionsIds["Taxation Reports"] = "Tables";
		$connectionsIds["system_user"] = "Tables";
		$connectionsIds["fiscal_year"] = "Tables";
		$connectionsIds["beg_bal"] = "Tables";
		$connectionsIds["ewt"] = "Tables";
		$connectionsIds["bank"] = "Tables";
		$connectionsIds["cost_center"] = "Tables";
		$connectionsIds["General Journal Reports"] = "Tables";
		$connectionsIds["Inventory Reports"] = "Tables";
		$connectionsIds["accounting_period"] = "Tables";
		$connectionsIds["bank_recon"] = "Tables";
		$connectionsIds["deposit"] = "Tables";
		$connectionsIds["account_classification"] = "Tables";
		$connectionsIds["chart_of_accounts"] = "Tables";
		$connectionsIds["recon_CR"] = "Tables";
		$connectionsIds["Recon_deposit"] = "Tables";
		$connectionsIds["Recon_CV"] = "Tables";
		$connectionsIds["Recon_GV_dep"] = "Tables";
		$connectionsIds["Recon_GV_CV"] = "Tables";
		$connectionsIds["vat_atc"] = "Tables";
		$connectionsIds["rdo"] = "Tables";
		$connectionsIds["2550q"] = "Tables";
		$connectionsIds["2550m"] = "Tables";
		$connectionsIds["dr"] = "Tables";
		$connectionsIds["purchase_order"] = "Tables";
		$connectionsIds["purchase_order_receiving"] = "Tables";
		$connectionsIds["System_preference"] = "Tables";
		$connectionsIds["ppe_list"] = "Tables";
		$connectionsIds["discounts"] = "Tables";
		$connectionsIds["item_group"] = "Tables";
		$connectionsIds["location"] = "Tables";
		$connectionsIds["meetings"] = "Tables";
		$connectionsIds["calls"] = "Tables";
		$connectionsIds["campaign"] = "Tables";
		$connectionsIds["reimbursement"] = "Tables";
		$connectionsIds["reimbursement_detail"] = "Tables";
		$connectionsIds["Target_customers"] = "Tables";
		$connectionsIds["quotation"] = "Tables";
		$connectionsIds["case"] = "Tables";
		$connectionsIds["projects"] = "Tables";
		$connectionsIds["production"] = "Tables";
		$connectionsIds["issue"] = "Tables";
		$connectionsIds["issue_detail"] = "Tables";
		$connectionsIds["disposed"] = "Tables";
		$connectionsIds["disposed_detail"] = "Tables";
		$connectionsIds["backload"] = "Tables";
		$connectionsIds["backload_detail"] = "Tables";
		$connectionsIds["vehicle"] = "Tables";
		$connectionsIds["payroll_item"] = "Tables";
		$connectionsIds["uom"] = "Tables";
		$connectionsIds["trip_ticket"] = "Tables";
		$connectionsIds["accident"] = "Tables";
		$connectionsIds["approver_list"] = "Tables";
		$connectionsIds["area"] = "Tables";
		$connectionsIds["attendance"] = "Tables";
		$connectionsIds["currency"] = "Tables";
		$connectionsIds["medical"] = "Tables";
		$connectionsIds["position"] = "Tables";
		$connectionsIds["service_center"] = "Tables";
		$connectionsIds["seminar"] = "Tables";
		$connectionsIds["service_report"] = "Tables";
		$connectionsIds["service_report_detail"] = "Tables";
		$connectionsIds["tax_status"] = "Tables";
		$connectionsIds["training"] = "Tables";
		$connectionsIds["competitor"] = "Tables";
		$connectionsIds["campaign_type"] = "Tables";
		$connectionsIds["fixed_asset_return_detail"] = "Tables";
		$connectionsIds["fixed_assets_return"] = "Tables";
		$connectionsIds["Prospect_customers"] = "Tables";
		$connectionsIds["trip_detail"] = "Tables";
		$connectionsIds["beg_baldetail"] = "Tables";
		$connectionsIds["cash_disbursement_detail2"] = "Tables";
		$connectionsIds["case_solutions"] = "Tables";
		$connectionsIds["cash_disbursment_detail"] = "Tables";
		$connectionsIds["cash_receipt_detail"] = "Tables";
		$connectionsIds["cash_receipt_detail2"] = "Tables";
		$connectionsIds["general_journal_detail"] = "Tables";
		$connectionsIds["employee_list"] = "Tables";
		$connectionsIds["petty_cash"] = "Tables";
		$connectionsIds["petty_cash_detail"] = "Tables";
		$connectionsIds["center_replenishment"] = "Tables";
		$connectionsIds["center_replenishment_detail"] = "Tables";
		$connectionsIds["credit_memo"] = "Tables";
		$connectionsIds["credit_memo_detail"] = "Tables";
		$connectionsIds["debit_memo"] = "Tables";
		$connectionsIds["debit_memo_detail"] = "Tables";
		$connectionsIds["project_replenishment"] = "Tables";
		$connectionsIds["project_replenishment_detail"] = "Tables";
		$connectionsIds["business_partner_group"] = "Tables";
		$connectionsIds["Sales_Representatives"] = "Tables";
		$connectionsIds["Types_of_leaves"] = "Tables";
		$connectionsIds["payroll_mode"] = "Tables";
		$connectionsIds["payroll_account_type"] = "Tables";
		$connectionsIds["Types_of_Overtime"] = "Tables";
		$connectionsIds["Types_of_Loan"] = "Tables";
		$connectionsIds["sales"] = "Tables";
		$connectionsIds["sales_detail"] = "Tables";
		$connectionsIds["Payroll_Company_Setup"] = "Tables";
		$connectionsIds["item_bill_of_materials"] = "Tables";
		$connectionsIds["item_uom_conversion"] = "Tables";
		$connectionsIds["tranasactions_for_approval"] = "Tables";
		$connectionsIds["deposit_detail"] = "Tables";
		$connectionsIds["purchase_detail"] = "Tables";
		$connectionsIds["dr_detail"] = "Tables";
		$connectionsIds["purchase_order_detail"] = "Tables";
		$connectionsIds["Sales_Order_for_checking"] = "Tables";
		$connectionsIds["sales_order_detail_for_checking"] = "Tables";
		$connectionsIds["Sales_Order_for_approval"] = "Tables";
		$connectionsIds["sales_order_detail_for_approval"] = "Tables";
		$connectionsIds["Quotation_for_approval"] = "Tables";
		$connectionsIds["Quotation_for_checking"] = "Tables";
		$connectionsIds["quotation_detail_for_checking"] = "Tables";
		$connectionsIds["quotation_detail_for_approval"] = "Tables";
		$connectionsIds["Reimbursement_for_checking"] = "Tables";
		$connectionsIds["reimbursement_detail_for_checking"] = "Tables";
		$connectionsIds["Reimbursement_for_approval"] = "Tables";
		$connectionsIds["reimbursement_detail_for_approval"] = "Tables";
		$connectionsIds["Project_Replenishment_for_checking"] = "Tables";
		$connectionsIds["project_replenishment_detail_for_checking"] = "Tables";
		$connectionsIds["Project_Replenishment_for_approval"] = "Tables";
		$connectionsIds["project_replenishment_detail_for_approval"] = "Tables";
		$connectionsIds["center_replenishment_detail_for_checking"] = "Tables";
		$connectionsIds["center_replenishment_detail_for_approval"] = "Tables";
		$connectionsIds["Purchases_Order_for_checking2"] = "Tables";
		$connectionsIds["purchase_order_detail_for_checking"] = "Tables";
		$connectionsIds["Purchases_Order_for_approval2"] = "Tables";
		$connectionsIds["purchase_order_detail_for_approval"] = "Tables";
		$connectionsIds["Receiving_for_checking2"] = "Tables";
		$connectionsIds["purchase_order_receiving_detail_for_checking"] = "Tables";
		$connectionsIds["Receiving_for_approval2"] = "Tables";
		$connectionsIds["purchase_order_receiving_detail_for_approval"] = "Tables";
		$connectionsIds["Delivery_Receipt_for_checking"] = "Tables";
		$connectionsIds["dr_detail_for_checking"] = "Tables";
		$connectionsIds["Delivery_Receipt_for_approval"] = "Tables";
		$connectionsIds["dr_detail_for_approval"] = "Tables";
		$connectionsIds["Production_for_checking"] = "Tables";
		$connectionsIds["production_detail_for_checking"] = "Tables";
		$connectionsIds["Production_for_approval"] = "Tables";
		$connectionsIds["production_detail_for_approval"] = "Tables";
		$connectionsIds["Issue_for_checking"] = "Tables";
		$connectionsIds["supply_issue_detail_for_checking"] = "Tables";
		$connectionsIds["Issue_for_approval"] = "Tables";
		$connectionsIds["supply_issue_detail_for_approval"] = "Tables";
		$connectionsIds["Return_for_checking"] = "Tables";
		$connectionsIds["supply_return_detail_for_checking"] = "Tables";
		$connectionsIds["Return_for_approval"] = "Tables";
		$connectionsIds["supply_return_detail_approval"] = "Tables";
		$connectionsIds["supply_disposed_detail_for_checking"] = "Tables";
		$connectionsIds["Disposal_for_approval"] = "Tables";
		$connectionsIds["supply_disposed_detail_for_approval"] = "Tables";
		$connectionsIds["Fixed_Asset_Issue_for_checking"] = "Tables";
		$connectionsIds["Fixed_Asset_Issue_for_approval"] = "Tables";
		$connectionsIds["fixed_asset_issue_detail_for_approval"] = "Tables";
		$connectionsIds["fixed_asset_issue_detail_for_checking"] = "Tables";
		$connectionsIds["Fixed_Asset_Return_for_checking"] = "Tables";
		$connectionsIds["fixed_asset_return_detail_for_checking"] = "Tables";
		$connectionsIds["Fixed_Asset_Return_for_approval"] = "Tables";
		$connectionsIds["fixed_asset_return_detail_for_approval"] = "Tables";
		$connectionsIds["Petty_Cash_for_checking"] = "Tables";
		$connectionsIds["petty_cash_detail_for_checking"] = "Tables";
		$connectionsIds["Petty_Cash_for_approval"] = "Tables";
		$connectionsIds["petty_cash_detail_for_approval"] = "Tables";
		$connectionsIds["Deposit_for_checking"] = "Tables";
		$connectionsIds["deposit_detail_for_checking"] = "Tables";
		$connectionsIds["Deposit_for_approval"] = "Tables";
		$connectionsIds["deposit_detail_for_approval"] = "Tables";
		$connectionsIds["Credit_Memo_for_checking"] = "Tables";
		$connectionsIds["credit_memo_detail_for_checking"] = "Tables";
		$connectionsIds["Credit_Memo_for_approval"] = "Tables";
		$connectionsIds["credit_memo_detail_for_approval"] = "Tables";
		$connectionsIds["Debit_Memo_for_checking"] = "Tables";
		$connectionsIds["debit_memo_detail_for_checking"] = "Tables";
		$connectionsIds["debit_memo_for_approval"] = "Tables";
		$connectionsIds["debit_memo_detail_for_approval"] = "Tables";
		$connectionsIds["Purchases_for_checking"] = "Tables";
		$connectionsIds["credit_purchase_detail_for_checking"] = "Tables";
		$connectionsIds["Purchases_for_approval"] = "Tables";
		$connectionsIds["credit_purchase_detail_for_approval"] = "Tables";
		$connectionsIds["Sales_for_checking"] = "Tables";
		$connectionsIds["Sales_for_approval"] = "Tables";
		$connectionsIds["credit_sales_detail_for_checking"] = "Tables";
		$connectionsIds["credit_sales_detail_for_approval"] = "Tables";
		$connectionsIds["Cash_Disbursement_for_checking"] = "Tables";
		$connectionsIds["check_voucher_detail_for_checking"] = "Tables";
		$connectionsIds["check_voucher_detail2_for_checking"] = "Tables";
		$connectionsIds["Cash_Disbursement_for_approval"] = "Tables";
		$connectionsIds["check_voucher_detail_for_approval"] = "Tables";
		$connectionsIds["check_voucher_detail2_for_approval"] = "Tables";
		$connectionsIds["document"] = "Tables";
		$connectionsIds["General_Journal_for_checking"] = "Tables";
		$connectionsIds["general_journal_detail_for_checking"] = "Tables";
		$connectionsIds["General_Journal_for_approval"] = "Tables";
		$connectionsIds["general_journal_detail_for_approval"] = "Tables";
		$connectionsIds["for_submissions"] = "Tables";
		$connectionsIds["submission_details"] = "Tables";
		$connectionsIds["sales_order_detail_billing_dates"] = "Tables";
		$connectionsIds["Submission_Search"] = "Tables";
		$connectionsIds["Submission_Reminders"] = "Tables";
		$connectionsIds["years"] = "Tables";
		$connectionsIds["document_type"] = "Tables";
		$connectionsIds["estimate"] = "Tables";
		$connectionsIds["estimate_detail"] = "Tables";
		$connectionsIds["purchase_request"] = "Tables";
		$connectionsIds["purchase_request_detail"] = "Tables";
		$connectionsIds["inv_adj_detail"] = "Tables";
		$connectionsIds["inventory_adj"] = "Tables";
		$connectionsIds["inventory_tranfer"] = "Tables";
		$connectionsIds["inventory_transfer_detail"] = "Tables";
		$connectionsIds["Customers"] = "Tables";
		$connectionsIds["Suppliers"] = "Tables";
		$connectionsIds["Target_contacts"] = "Tables";
		$connectionsIds["Prospect_contacts"] = "Tables";
		$connectionsIds["Customer_Contacts"] = "Tables";
		$connectionsIds["Supplier_Contacts"] = "Tables";
		$connectionsIds["Statement_of_Account"] = "Tables";
		$connectionsIds["Change_Time_Schedule_for_approval"] = "Tables";
		$connectionsIds["Change_Time_Schedule_for_checking"] = "Tables";
		$connectionsIds["Inventory_Adjustment_for_checking"] = "Tables";
		$connectionsIds["inv_adj_detail_for_checking"] = "Tables";
		$connectionsIds["Inventory_Adjustment_for_approval"] = "Tables";
		$connectionsIds["inv_adj_detail_for_approval"] = "Tables";
		$connectionsIds["for_checking"] = "Tables";
		$connectionsIds["for_approval"] = "Tables";
		$connectionsIds["Estimate_for_approval"] = "Tables";
		$connectionsIds["Estimate_for_checking"] = "Tables";
		$connectionsIds["estimate_detail_for_checking"] = "Tables";
		$connectionsIds["estimate_detail_for_approval"] = "Tables";
		$connectionsIds["Follow_up"] = "Tables";
		$connectionsIds["coming_meetings"] = "Tables";
		$connectionsIds["tasks"] = "Tables";
		$connectionsIds["Project_phases"] = "Tables";
		$connectionsIds["origin_fa"] = "Tables";
		$connectionsIds["origin_serialized_supply"] = "Tables";
		$connectionsIds["2301"] = "Tables";
		$connectionsIds["Prospect_customers_to_Customer"] = "Tables";
		$connectionsIds["lyl_estimate"] = "Tables";
		$connectionsIds["lyl_estimate_detail"] = "Tables";
		$connectionsIds["lyl_estimate_detail_accessories"] = "Tables";
		$connectionsIds["lyl_estimate_detail_aluminum"] = "Tables";
		$connectionsIds["lyl_estimate_detail_e_accessories"] = "Tables";
		$connectionsIds["lyl_estimate_detail_glass"] = "Tables";
		$connectionsIds["recuring_benefits"] = "Tables";
		$connectionsIds["recuring_deductions"] = "Tables";
		$connectionsIds["recurring_benefits_detail"] = "Tables";
		$connectionsIds["recurring_deductions_detail"] = "Tables";
		$connectionsIds["production_request"] = "Tables";
		$connectionsIds["production_request_detail"] = "Tables";
		$connectionsIds["attendance_summary"] = "Tables";
		$connectionsIds["Other_Incentives"] = "Tables";
		$connectionsIds["Other_Deductions"] = "Tables";
		$connectionsIds["department"] = "Tables";
		$connectionsIds["journal_entry_cash_disbursement"] = "Tables";
		$connectionsIds["journal_entry_cash_receipt"] = "Tables";
		$connectionsIds["journal_entry_center_replenishment"] = "Tables";
		$connectionsIds["journal_entry_credit_memo"] = "Tables";
		$connectionsIds["journal_entry_debit_memo"] = "Tables";
		$connectionsIds["journal_entry_depreciation"] = "Tables";
		$connectionsIds["journal_entry_general_journal"] = "Tables";
		$connectionsIds["journal_entry_inventory_adjustment"] = "Tables";
		$connectionsIds["journal_entry_petty_cash"] = "Tables";
		$connectionsIds["journal_entry_project_replenishment"] = "Tables";
		$connectionsIds["journal_entry_purchases"] = "Tables";
		$connectionsIds["journal_entry_replenishment"] = "Tables";
		$connectionsIds["journal_entry_service_revenue"] = "Tables";
		$connectionsIds["Credit_Card_monitoring"] = "Tables";
		$connectionsIds["sales_report_per_item Chart"] = "Tables";
		$connectionsIds["Leave_for_approval"] = "Tables";
		$connectionsIds["loan_for_approval"] = "Tables";
		$connectionsIds["loan_detail_for_approval"] = "Tables";
		$connectionsIds["Overtime_for_approval"] = "Tables";
		$connectionsIds["Purchase_Request_for_approval"] = "Tables";
		$connectionsIds["purchase_request_detail_approval"] = "Tables";
		$connectionsIds["Production_Request_for_approval"] = "Tables";
		$connectionsIds["production_request_detail_for_approval"] = "Tables";
		$connectionsIds["Inventory_Transfer_for_approval"] = "Tables";
		$connectionsIds["inventory_transfer_detail_for_approval"] = "Tables";
		$connectionsIds["Leave_for_checking"] = "Tables";
		$connectionsIds["Loan_for_checking"] = "Tables";
		$connectionsIds["loan_detail_for_checking"] = "Tables";
		$connectionsIds["Overtime_for_checking"] = "Tables";
		$connectionsIds["Purchase_Request_for_checking"] = "Tables";
		$connectionsIds["Production_Request_for_checking"] = "Tables";
		$connectionsIds["Inventory_Transfer_for_checking"] = "Tables";
		$connectionsIds["inventory_transfer_detail_for_checking"] = "Tables";
		$connectionsIds["attendance_type"] = "Tables";
		$connectionsIds["Backload_for_approval"] = "Tables";
		$connectionsIds["backload_detail_for_approval"] = "Tables";
		$connectionsIds["Backload_for_checking"] = "Tables";
		$connectionsIds["backload_detail_for_checking"] = "Tables";
		$connectionsIds["Cash_Receipt_for_approval"] = "Tables";
		$connectionsIds["Cash_Receipt_for_checking"] = "Tables";
		$connectionsIds["cash_receipt_detail_for_checking"] = "Tables";
		$connectionsIds["cash_receipt_detail_for_approval"] = "Tables";
		$connectionsIds["Payroll_Entry_for_approval"] = "Tables";
		$connectionsIds["Payroll_Entry_for_checking"] = "Tables";
		$connectionsIds["payroll_entry_detail_for_approval"] = "Tables";
		$connectionsIds["payroll_entry_detail_for_checking"] = "Tables";
		$connectionsIds["Process_Payroll_for_approval"] = "Tables";
		$connectionsIds["Process_Payroll_for_checking"] = "Tables";
		$connectionsIds["process_payroll_detail_for_approval"] = "Tables";
		$connectionsIds["process_payroll_detail_for_checking"] = "Tables";
		$connectionsIds["Service_Report_for_approval"] = "Tables";
		$connectionsIds["Service_Report_for_checking"] = "Tables";
		$connectionsIds["service_report_detail_for_approval"] = "Tables";
		$connectionsIds["service_report_detail_for_checking"] = "Tables";
		$connectionsIds["Banch Reports"] = "Tables";
		$connectionsIds["journal_entry_production"] = "Tables";
		$connectionsIds["journal_entry_deposit"] = "Tables";
		$connectionsIds["production_request_bom"] = "Tables";
		$connectionsIds["production_bom"] = "Tables";
		$connectionsIds["company_info"] = "Tables";
		$connectionsIds["return"] = "Tables";
		$connectionsIds["return_detail"] = "Tables";
		$connectionsIds["fixed_asset_issue"] = "Tables";
		$connectionsIds["fixed_asset_issue_detail"] = "Tables";
		$connectionsIds["production_request_detail_for_checking"] = "Tables";
		$connectionsIds["cash_disbursment_detail_for_approval"] = "Tables";
		$connectionsIds["cash_disbursment_detail_for_checking"] = "Tables";
		$connectionsIds["purchase_request_detail_for_checking"] = "Tables";
		$connectionsIds["trip_ticket_for_approval"] = "Tables";
		$connectionsIds["trip_ticket_for_checking"] = "Tables";
		$connectionsIds["trip_detail_for_approval"] = "Tables";
		$connectionsIds["trip_detail_for_checking"] = "Tables";
		$connectionsIds["sales_report"] = "Tables";
		$connectionsIds["Customer_Balance_Report"] = "Tables";
		$connectionsIds["Customer_Balance_Report_detail"] = "Tables";
		$connectionsIds["Collection_Report_per_Customer"] = "Tables";
		$connectionsIds["Aging_of_AR_Report"] = "Tables";
		$connectionsIds["Aging_of_AR_Report_detail"] = "Tables";
		$connectionsIds["Payment_per_Supplier_Report"] = "Tables";
		$connectionsIds["Aging of_AP_Report"] = "Tables";
		$connectionsIds["Aging of_AP_Report_detail"] = "Tables";
		$connectionsIds["Inventory_Balance_Report"] = "Tables";
		$connectionsIds["Inventory_Valuation_Report"] = "Tables";
		$connectionsIds["Inventory_Below_Reorder_Point_Report"] = "Tables";
		$connectionsIds["Sales_Report_per_BP"] = "Tables";
		$connectionsIds["Sales_Report_per_Item"] = "Tables";
		$connectionsIds["Sales_Report_per_Cost_Center"] = "Tables";
		$connectionsIds["Sales_Report_per_BP_detail"] = "Tables";
		$connectionsIds["Sales_Report_per_Item_detail"] = "Tables";
		$connectionsIds["Sales_Report_per_Cost_Center_detail"] = "Tables";
		$connectionsIds["Purchase_Report"] = "Tables";
		$connectionsIds["Purchase_Report_per_BP"] = "Tables";
		$connectionsIds["Purchase_Report_per_Item"] = "Tables";
		$connectionsIds["Purchase_Report_per_Cost_Center"] = "Tables";
		$connectionsIds["Purchase_Report_per_BP_detail"] = "Tables";
		$connectionsIds["Purchase_Report_per_Item_detail"] = "Tables";
		$connectionsIds["Purchase_Report_per_Cost_Center_detail"] = "Tables";
		$connectionsIds["Transaction Registry"] = "Tables";
		$connectionsIds["Sales_Report_per_sales_rep"] = "Tables";
		$connectionsIds["PDC_Registry_Report"] = "Tables";
		$connectionsIds["Available_Vehicles"] = "Tables";
		$connectionsIds["Trip_Ticket_Report"] = "Tables";
		$connectionsIds["Purchase_Request_Report"] = "Tables";
		$connectionsIds["Purchase_Import_Costing"] = "Tables";
		$connectionsIds["Production_Costing_Report"] = "Tables";
		$connectionsIds["Production_Report"] = "Tables";
		$connectionsIds["Closed_Opportunities"] = "Tables";
		$connectionsIds["Cases_with_Sotutions"] = "Tables";
		$connectionsIds["Totals_Cases_Created"] = "Tables";
		$connectionsIds["Totals_Open_Cases_by_Agent"] = "Tables";
		$connectionsIds["Campaign_Contacts"] = "Tables";
		$connectionsIds["Campaign_leads"] = "Tables";
		$connectionsIds["Campaign_ROI_Analysis"] = "Tables";
		$connectionsIds["Campaign_Revenue"] = "Tables";
		$connectionsIds["Opportunity_Schedule"] = "Tables";
		$connectionsIds["Sales_by_Account"] = "Tables";
		$connectionsIds["Sales_by_Lead_Source"] = "Tables";
		$connectionsIds["Sales_by_Partner"] = "Tables";
		$connectionsIds["Sales_by_Rep"] = "Tables";
		$connectionsIds["Leave_Ledger_Report"] = "Tables";
		$connectionsIds["Leave_Summary"] = "Tables";
		$connectionsIds["Payroll_Register"] = "Tables";
		$connectionsIds["Employee_Leave_History"] = "Tables";
		$connectionsIds["Employee_Register"] = "Tables";
		$connectionsIds["DR_Reports"] = "Tables";
		$connectionsIds["Sales_Order_Report"] = "Tables";
		$connectionsIds["Case_History"] = "Tables";
		$connectionsIds["quality_control"] = "Tables";
		$connectionsIds["quality_control_detail"] = "Tables";
		$connectionsIds["budget"] = "Tables";
		$connectionsIds["budget_detail"] = "Tables";
		$connectionsIds["repairs_and_maintenance"] = "Tables";
		$connectionsIds["production_form"] = "Tables";
		$connectionsIds["bluewave_employees"] = "Tables";
		$connectionsIds["bluewave_employees_detail"] = "Tables";
		$connectionsIds["bluewave_employees_detail2"] = "Tables";
		$connectionsIds["bluewave_employees_detail3"] = "Tables";
		$connectionsIds["bluewave_employees_detail4"] = "Tables";
		$connectionsIds["bluewave_employees_detail5"] = "Tables";
		$connectionsIds["bluewave_employees_detail6"] = "Tables";
		$connectionsIds["rfp"] = "Tables";
		$connectionsIds["telex"] = "Tables";
		$connectionsIds["repairs_and_maintenance_detail"] = "Tables";
		$connectionsIds["repair_list"] = "Tables";
		$connectionsIds["marketing_colateral"] = "Tables";
		$connectionsIds["email"] = "Tables";
		$connectionsIds["accessories"] = "Tables";
		$connectionsIds["sales_order_materials_detail"] = "Tables";
		$connectionsIds["sales_order_progress_billing_detail"] = "Tables";
		$connectionsIds["sub_contract"] = "Tables";
		$connectionsIds["sub_contract_billing_detail"] = "Tables";
		$connectionsIds["sub_contract_detail"] = "Tables";
		$connectionsIds["Monthly_Pag-ibig_Summary_Report"] = "Tables";
		$connectionsIds["Monthly_Philhealth_Report"] = "Tables";
		$connectionsIds["Monthly_Philhealth_Summary_Report"] = "Tables";
		$connectionsIds["Monthly_SSS_Report"] = "Tables";
		$connectionsIds["Monthly_SSS_Report_by_Department_Report"] = "Tables";
		$connectionsIds["Monthly_Withholding_Tax_Prooflist_Report"] = "Tables";
		$connectionsIds["Monthly_Witholding_Tax_Collection_List_by_Department_Report"] = "Tables";
		$connectionsIds["Overtime_Summary_Report"] = "Tables";
		$connectionsIds["Monthly_Pag-ibig_Report"] = "Tables";
		$connectionsIds["sales_order"] = "Tables";
		$connectionsIds["sales_order_detail"] = "Tables";
		$connectionsIds["vat_relief_importation"] = "Tables";
		$connectionsIds["vat_relief_purchases"] = "Tables";
		$connectionsIds["vat_relief_sales"] = "Tables";
		$connectionsIds["journal_ppe_disposal"] = "Tables";
		$connectionsIds["credit_memo_detail_cgs"] = "Tables";
		$connectionsIds["marketing_request_form"] = "Tables";
		$connectionsIds["Quotation_Dashboard_Customer"] = "Tables";
		$connectionsIds["Sales_Order_Dashboard_Customer"] = "Tables";
		$connectionsIds["Delivery_Receipt_Dashboard_Customer"] = "Tables";
		$connectionsIds["Sales_Dashboard_Customer"] = "Tables";
		$connectionsIds["Backload_Dashboard_Customer"] = "Tables";
		$connectionsIds["Purchase_Request_Dashboard_Supplier"] = "Tables";
		$connectionsIds["Purchase_Order_Dashboard_Supplier"] = "Tables";
		$connectionsIds["Purchase_Dashboard_Supplier"] = "Tables";
		$connectionsIds["Cash_Disbursement_Dashboard_Supplier"] = "Tables";
		$connectionsIds["Debit_Memo_Dashboard_Supplier"] = "Tables";
		$connectionsIds["Purchase_Request_Dashboard_Item"] = "Tables";
		$connectionsIds["Purchase_Order_Dashboard_Item"] = "Tables";
		$connectionsIds["Purchase_Order_Receiving_Dashboard_Item"] = "Tables";
		$connectionsIds["Production_Dashboard_Item"] = "Tables";
		$connectionsIds["sub_contract_for_approval"] = "Tables";
		$connectionsIds["sub_contract_for_checking"] = "Tables";
		$connectionsIds["sub_contract_detail_for_approval"] = "Tables";
		$connectionsIds["sub_contract_detail_for_checking"] = "Tables";
		$connectionsIds["budget_for_approval"] = "Tables";
		$connectionsIds["budget_for_checking"] = "Tables";
		$connectionsIds["budget_detail_for_checking"] = "Tables";
		$connectionsIds["budget_detail_for_approval"] = "Tables";
		$connectionsIds["undertime_for_approval"] = "Tables";
		$connectionsIds["undertime_for_checking"] = "Tables";
		$connectionsIds["request_for_payment_for_approval"] = "Tables";
		$connectionsIds["request_for_payment_for_checking"] = "Tables";
		$connectionsIds["repairs_and_maintenance_detail_for_approval"] = "Tables";
		$connectionsIds["request_for_payment_detail_for_approval"] = "Tables";
		$connectionsIds["request_for_payment_detail_for_checking"] = "Tables";
		$connectionsIds["repairs_and_maintenance_for_approval"] = "Tables";
		$connectionsIds["repairs_and_maintenance_for_checking"] = "Tables";
		$connectionsIds["repairs_and_maintenance_detail_for_checking"] = "Tables";
		$connectionsIds["Disposal_for_checking"] = "Tables";
		$connectionsIds["Active_campaign_report"] = "Tables";
		$connectionsIds["For_Billing_report"] = "Tables";
		$connectionsIds["sales_order_for_project_mngmt"] = "Tables";
		$connectionsIds["inventory_transfer_cost_detail"] = "Tables";
		$connectionsIds["Supplier_Balance_Report_Details"] = "Tables";
		$connectionsIds["Supplier_Balance_Report"] = "Tables";
		$connectionsIds["Inventory_per_Cost_center_Report"] = "Tables";
		$connectionsIds["Deposit_Report"] = "Tables";
		$connectionsIds["SO_for_Billing_Report"] = "Tables";
		$connectionsIds["Billing_due_dates_Report"] = "Tables";
		$connectionsIds["Packing_List_Report"] = "Tables";
		$connectionsIds["Open_Trip_Ticket_Report"] = "Tables";
		$connectionsIds["Transfer_Report"] = "Tables";
		$connectionsIds["Production_Report_invw"] = "Tables";
		$connectionsIds["Supply_per_Department__Report_invw"] = "Tables";
		$connectionsIds["Item_Balances_Report_invw"] = "Tables";
		$connectionsIds["Open_Case_Report_s"] = "Tables";
		$connectionsIds["Sales_Order_per_Campaign_Report_marketing"] = "Tables";
		$connectionsIds["Sales_per_campaign_Report_marketing"] = "Tables";
		$connectionsIds["Asset_per_Accountability_Report_invw"] = "Tables";
		$connectionsIds["Deposit_in_transit_Report"] = "Tables";
		$connectionsIds["Outstanding_Checks_Report"] = "Tables";
		$connectionsIds["Absences_Detail_Report"] = "Tables";
		$connectionsIds["Absences_Report"] = "Tables";
		$connectionsIds["Attendance_Report"] = "Tables";
		$connectionsIds["DTR_Report"] = "Tables";
		$connectionsIds["Summary_of_Tardiness_Report"] = "Tables";
		$connectionsIds["Followup_Report"] = "Tables";
		$connectionsIds["Coming_Meeting_Report"] = "Tables";
		$connectionsIds["Meeting_Report"] = "Tables";
		$connectionsIds["Next_Action_Report"] = "Tables";
		$connectionsIds["Calls_Report"] = "Tables";
		$connectionsIds["sales_per_sales_rep_Report"] = "Tables";
		$connectionsIds["Expense_per_Project_Report"] = "Tables";
		$connectionsIds["Tardiness_Report_Summary"] = "Tables";
		$connectionsIds["Timekeeping_(Hours_Worked)_Report_Summary"] = "Tables";
		$connectionsIds["Withholding_Tax_Collection_List_per_Month_Report"] = "Tables";
		$connectionsIds["purchase_report_per_item Chart"] = "Tables";
		$connectionsIds["System_Audit_Report"] = "Tables";
		$connectionsIds["sale_cost_detail"] = "Tables";
		$connectionsIds["currency_exchange_rate"] = "Tables";
		$connectionsIds["cash_receipt_cost_detail"] = "Tables";
		$connectionsIds["production_cost_detail"] = "Tables";
		$connectionsIds["Quotation_Dashboard"] = "Tables";
		$connectionsIds["Sales_Order_Dashboard"] = "Tables";
		$connectionsIds["Reimbursement_Dashboard"] = "Tables";
		$connectionsIds["Transaction_Registry_Dashboard_SaleRep"] = "Tables";
		$connectionsIds["Loan_Dashboard"] = "Tables";
		$connectionsIds["Leave_Dashboard"] = "Tables";
		$connectionsIds["Over_Time_Dashboard"] = "Tables";
		$connectionsIds["Undertime_Dashboard"] = "Tables";
		$connectionsIds["Fieldwork_Dashboard"] = "Tables";
		$connectionsIds["Change_Time_Dashboard"] = "Tables";
		$connectionsIds["Transaction_Registry_Dashboard_Employee"] = "Tables";
		$connectionsIds["Transaction_Registry_Dashboard_Supplier"] = "Tables";
		$connectionsIds["Transaction_Registry_Dashboard_Customer"] = "Tables";
		$connectionsIds["lyl_estimate_dr"] = "Tables";
		$connectionsIds["lyl_estimate_dr_detail"] = "Tables";
		$connectionsIds["lyl_estimate_dr_detail_accessories"] = "Tables";
		$connectionsIds["lyl_estimate_dr_detail_aluminum"] = "Tables";
		$connectionsIds["lyl_estimate_dr_detail_e_accessories"] = "Tables";
		$connectionsIds["lyl_estimate_dr_detail_glass"] = "Tables";
		$connectionsIds["sum_dr_qty"] = "Tables";
		$connectionsIds["check_book_registry"] = "Tables";
		$connectionsIds["check_book_registry_detail"] = "Tables";
		$connectionsIds["vat_type"] = "Tables";
		$connectionsIds["quotation_detail"] = "Tables";
		$connectionsIds["bal_purchase_order_detail"] = "Tables";
		$connectionsIds["bal_sales_detail"] = "Tables";
		$connectionsIds["pending_items_reminders"] = "Tables";
		$connectionsIds["petty_cash_for_liquidation"] = "Tables";
		$connectionsIds["payment_method"] = "Tables";
		$connectionsIds["account_type"] = "Tables";
		$connectionsIds["phase"] = "Tables";
		$connectionsIds["item_cost_recalculation"] = "Tables";
		$connectionsIds["issue_components"] = "Tables";
		$connectionsIds["issue_components_detail"] = "Tables";
		$connectionsIds["unbuild_assemblies"] = "Tables";
		$connectionsIds["unbuild_assemblies_detail"] = "Tables";
		$connectionsIds["demand_plan"] = "Tables";
		$connectionsIds["input_vat_allocation"] = "Tables";
		$connectionsIds["case_type"] = "Tables";
		$connectionsIds["qc_inspection"] = "Tables";
		$connectionsIds["packing_list_for_checking"] = "Tables";
		$connectionsIds["packing_list_for_approval"] = "Tables";
		$connectionsIds["packing_list_detail_for_checking"] = "Tables";
		$connectionsIds["packing_list_detail_for_approval"] = "Tables";
		$connectionsIds["disposed_inv_detail"] = "Tables";
		$connectionsIds["disposed_inv"] = "Tables";
		$connectionsIds["disposed_inv_for_checking"] = "Tables";
		$connectionsIds["disposed_inv_for_approval"] = "Tables";
		$connectionsIds["disposed_inv_detail_for_checking"] = "Tables";
		$connectionsIds["disposed_inv_detail_for_approval"] = "Tables";
		$connectionsIds["For_Approval_Dashboard"] = "Tables";
		$connectionsIds["For_Checking_Dashboard"] = "Tables";
		$connectionsIds["Customer_For_Approval"] = "Tables";
		$connectionsIds["request_for_payment_report"] = "Tables";
		$connectionsIds["credit_memo_report"] = "Tables";
		$connectionsIds["debit_memo_report"] = "Tables";
		$connectionsIds["production_request_report"] = "Tables";
		$connectionsIds["Supplies_Balance_report"] = "Tables";
		$connectionsIds["approved_sales_order"] = "Tables";
		$connectionsIds["purchase_order_for_receiving"] = "Tables";
		$connectionsIds["packing_list"] = "Tables";
		$connectionsIds["packing_list_detail"] = "Tables";
		$connectionsIds["open_quote"] = "Tables";
		$connectionsIds["open_estimates"] = "Tables";
		$connectionsIds["open_po"] = "Tables";
		$connectionsIds["open_pr"] = "Tables";
		$connectionsIds["open_production_request"] = "Tables";
		$connectionsIds["open_qc"] = "Tables";
		$connectionsIds["open_receiving"] = "Tables";
		$connectionsIds["open_request_for_payment"] = "Tables";
		$connectionsIds["open_so"] = "Tables";
		$connectionsIds["open_so_for_invoice"] = "Tables";
		$connectionsIds["open_so_for_project_management"] = "Tables";
		$connectionsIds["open_backload"] = "Tables";
		$connectionsIds["purchase_order_receiving_detail"] = "Tables";
		$connectionsIds["Purchase_Order_Receiving_Dashboard_Supplier"] = "Tables";
		$connectionsIds["avg_inv"] = "Tables";
		$connectionsIds["open_backload_Report"] = "Tables";
		$connectionsIds["open_estimates_Report"] = "Tables";
		$connectionsIds["open_po_Report"] = "Tables";
		$connectionsIds["open_pr_Report"] = "Tables";
		$connectionsIds["open_production_request_Report"] = "Tables";
		$connectionsIds["open_qc_Report"] = "Tables";
		$connectionsIds["open_so_for_project_management_Report"] = "Tables";
		$connectionsIds["open_so_for_invoice_Report"] = "Tables";
		$connectionsIds["open_so_Report"] = "Tables";
		$connectionsIds["open_receiving_Report"] = "Tables";
		$connectionsIds["monthly_consuption_for_production_Report"] = "Tables";
		$connectionsIds["issue_components_for_approval"] = "Tables";
		$connectionsIds["issue_components_for_checking"] = "Tables";
		$connectionsIds["issue_components_detail_for_checking"] = "Tables";
		$connectionsIds["issue_components_detail_for_approval"] = "Tables";
		$connectionsIds["fieldwork_for_approval"] = "Tables";
		$connectionsIds["fieldwork_for_checking"] = "Tables";
		$connectionsIds["Purchases_Order_for_checking"] = "Tables";
		$connectionsIds["Purchases_Order_for_approval"] = "Tables";
		$connectionsIds["Receiving_for_checking"] = "Tables";
		$connectionsIds["Receiving_for_approval"] = "Tables";
		$connectionsIds["inventory_tranfer_Report"] = "Tables";
		$connectionsIds["Purchase_vs_Production_Report"] = "Tables";
		$connectionsIds["cash_sales_Report"] = "Tables";
		$connectionsIds["Center_Replenishment_for_approval"] = "Tables";
		$connectionsIds["Center_Replenishment_for_checking"] = "Tables";
		$connectionsIds["Purchase_vs_Production"] = "Tables";
		$connectionsIds["Production_Summary"] = "Tables";
		$connectionsIds["pending_production_request"] = "Tables";
		$connectionsIds["unbuild_assemblies_for_checking"] = "Tables";
		$connectionsIds["unbuild_assemblies_for_approval"] = "Tables";
		$connectionsIds["unbuild_assemblies_detail_for_checking"] = "Tables";
		$connectionsIds["quality_control_for_approval"] = "Tables";
		$connectionsIds["quality_control_for_checking"] = "Tables";
		$connectionsIds["quality_control_detail_for_approval"] = "Tables";
		$connectionsIds["raw_cake_balance"] = "Tables";
		$connectionsIds["bal_cashreceipt"] = "Tables";
		$connectionsIds["bal_cashpayment"] = "Tables";
		$connectionsIds["opportunity"] = "Tables";
		$connectionsIds["Current_Accounts"] = "Tables";
		$connectionsIds["bal_lyl_acc"] = "Tables";
		$connectionsIds["bal_lyl_glass"] = "Tables";
		$connectionsIds["bal_lyl_eacc"] = "Tables";
		$connectionsIds["bal_lyl_allum"] = "Tables";
		$connectionsIds["opportunity_details"] = "Tables";
		$connectionsIds["Collection_Report_per_Sales_Rep"] = "Tables";
		$connectionsIds["Inventory_per_lot_no"] = "Tables";
		$connectionsIds["marketing_request_form_for_checking"] = "Tables";
		$connectionsIds["marketing_request_form_for_approval"] = "Tables";
		$connectionsIds["201"] = "Tables";
		$connectionsIds["Cashflow_forcast"] = "Tables";
		$connectionsIds["Business_Owner_Sales_Report"] = "Tables";
		$connectionsIds["Business_Owner_Purchase_Report"] = "Tables";
		$connectionsIds["Business_Owner_Cash_Balance"] = "Tables";
		$connectionsIds["Business_Owner_Top_Customer_Income"] = "Tables";
		$connectionsIds["AR_Billing_due_dates_Report"] = "Tables";
		$connectionsIds["AR_Aging_of_AR_Report"] = "Tables";
		$connectionsIds["AR_Top_5_Customer_balances"] = "Tables";
		$connectionsIds["AR_Progress_Billing_Alert"] = "Tables";
		$connectionsIds["Finance_Cash_Balance"] = "Tables";
		$connectionsIds["Finance_approved_request_for_payment"] = "Tables";
		$connectionsIds["Finance_Cash_flow_forcast"] = "Tables";
		$connectionsIds["Finance_Approved_Employee_Loan"] = "Tables";
		$connectionsIds["Finance_Cash_Balances"] = "Tables";
		$connectionsIds["AP_Aging_of_Payables"] = "Tables";
		$connectionsIds["Purchasing_Item_below_reorder"] = "Tables";
		$connectionsIds["production_per_item"] = "Tables";
		$connectionsIds["AP_Top_5_Supplier_balances"] = "Tables";
		$connectionsIds["Warehouse_Item_balances"] = "Tables";
		$connectionsIds["DR_per_Item"] = "Tables";
		$connectionsIds["Logistic_Open_Trip_Ticket"] = "Tables";
		$connectionsIds["Logistic_Available_Vehicles"] = "Tables";
		$connectionsIds["Marketing_Open_Campaign"] = "Tables";
		$connectionsIds["Marketing_Sales_per_campaign"] = "Tables";
		$connectionsIds["Support_Open_Case_Report"] = "Tables";
		$connectionsIds["Support_Service_center"] = "Tables";
		$connectionsIds["Sale_Meeting_Report"] = "Tables";
		$connectionsIds["Sales_Next_Action_Report"] = "Tables";
		$connectionsIds["HR_attendance_summary"] = "Tables";
		$connectionsIds["HR_Birthday_Alert"] = "Tables";
		$connectionsIds["HR_holiday"] = "Tables";
		$connectionsIds["Project_Expense_per_Project"] = "Tables";
		$connectionsIds["Project_Expense_per_Project_graph"] = "Tables";
		$connectionsIds["Petty_Cash_Balance"] = "Tables";
		$connectionsIds["Petty_Cash_Unliquidated"] = "Tables";
		$connectionsIds["Petty_Cash_Purchases_per_Item"] = "Tables";
		$connectionsIds["Accounting_Income_per_Center"] = "Tables";
		$connectionsIds["open_quote_Report"] = "Tables";
		$connectionsIds["Open_cases_per_agent"] = "Tables";
		$connectionsIds["Marketing_sales_per_campaing_chart"] = "Tables";
		$connectionsIds["AP_open_po_receiving"] = "Tables";
		$connectionsIds["Production_Inventory_Balance_Report"] = "Tables";
		$connectionsIds["Production_WIP"] = "Tables";
		$connectionsIds["Warehouse_Inventory_Balance_Report"] = "Tables";
		$connectionsIds["logistic_open_inventory_tranfer"] = "Tables";
		$connectionsIds["Sales_Leads"] = "Tables";
		$connectionsIds["Sales_opportunity_Next_Action"] = "Tables";
		$connectionsIds["Sales_Active_opportunity"] = "Tables";
		$connectionsIds["intercompany_sales_order_detail"] = "Tables";
		$connectionsIds["intercompany_sales_order"] = "Tables";
		$connectionsIds["production_detail"] = "Tables";
		$connectionsIds["quality_control_detail_for_checking"] = "Tables";
		$connectionsIds["lyl_estimate_for_approval"] = "Tables";
		$connectionsIds["lyl_estimate_dr_for_approval"] = "Tables";
		$connectionsIds["lyl_estimate_detail_for_approval"] = "Tables";
		$connectionsIds["lyl_estimate_detail_accessories_for_approval"] = "Tables";
		$connectionsIds["lyl_estimate_detail_aluminum_for_approval"] = "Tables";
		$connectionsIds["lyl_estimate_detail_e_accessories_for_approval"] = "Tables";
		$connectionsIds["lyl_estimate_detail_glass_for_approval"] = "Tables";
		$connectionsIds["lyl_estimate_dr_detail_for_approval"] = "Tables";
		$connectionsIds["lyl_estimate_dr_detail_accessories_for_approval"] = "Tables";
		$connectionsIds["lyl_estimate_dr_detail_aluminum_for_approval"] = "Tables";
		$connectionsIds["lyl_estimate_dr_detail_e_accessories_for_approval"] = "Tables";
		$connectionsIds["lyl_estimate_dr_detail_glass_for_approval"] = "Tables";
		$connectionsIds["lyl_estimate_for_checking"] = "Tables";
		$connectionsIds["lyl_estimate_detail_for_checking"] = "Tables";
		$connectionsIds["lyl_estimate_detail_accessories_for_checking"] = "Tables";
		$connectionsIds["lyl_estimate_detail_aluminum_for_checking"] = "Tables";
		$connectionsIds["lyl_estimate_detail_e_accessories_for_checking"] = "Tables";
		$connectionsIds["lyl_estimate_detail_glass_for_checking"] = "Tables";
		$connectionsIds["lyl_estimate_dr_for_checking"] = "Tables";
		$connectionsIds["lyl_estimate_dr_detail_for_checking"] = "Tables";
		$connectionsIds["lyl_estimate_dr_detail_accessories_for_checking"] = "Tables";
		$connectionsIds["lyl_estimate_dr_detail_aluminum_for_checking"] = "Tables";
		$connectionsIds["lyl_estimate_dr_detail_e_accessories_for_checking"] = "Tables";
		$connectionsIds["lyl_estimate_dr_detail_glass_for_checking"] = "Tables";
		$connectionsIds["EWT_Certificates_summay"] = "Tables";
		$connectionsIds["1601e"] = "Tables";
		$connectionsIds["1601eform"] = "Tables";
		$connectionsIds["1601fform"] = "Tables";
		$connectionsIds["tax_person_status"] = "Tables";
		$connectionsIds["journal_entry_inv_transfer"] = "Tables";
		$connectionsIds["Recon_withdraw"] = "Tables";
		$connectionsIds["lot"] = "Tables";
		$connectionsIds["serial_no"] = "Tables";
		$connectionsIds["request_for_quote"] = "Tables";
		$connectionsIds["request_for_quoter_detail"] = "Tables";
		$connectionsIds["request_for_quote_for_checking"] = "Tables";
		$connectionsIds["request_for_quote_for_approval"] = "Tables";
		$connectionsIds["request_for_quoter_detail_for_checking"] = "Tables";
		$connectionsIds["request_for_quoter_detail_for_approval"] = "Tables";
		$connectionsIds["estimate_cost"] = "Tables";
		$connectionsIds["airlines"] = "Tables";
		$connectionsIds["airport"] = "Tables";
		$connectionsIds["inco_terms"] = "Tables";
		$connectionsIds["seaports"] = "Tables";
		$connectionsIds["shipment_classification"] = "Tables";
		$connectionsIds["shipping_lines"] = "Tables";
		$connectionsIds["bal_sales_order_detail"] = "Tables";
		$connectionsIds["project_cont_seal"] = "Tables";
		$connectionsIds["project_house"] = "Tables";
		$connectionsIds["billable_liquidation"] = "Tables";
		$connectionsIds["billable_pettycash"] = "Tables";
		$connectionsIds["billable_checkvoucher"] = "Tables";
		$connectionsIds["projects_dashboard"] = "Tables";
		$connectionsIds["employees"] = "Tables";
		$connectionsIds["admin_rights"] = "Tables";
		$connectionsIds["admin_members"] = "Tables";
		$connectionsIds["admin_users"] = "Tables";
		$connectionsIds["company"] = "Tables";
		$connectionsIds["notifiy quotation Report"] = "Tables";
		$connectionsIds["expenses Report"] = "Tables";
		$connectionsIds["petty cash release"] = "Tables";
		$connectionsIds["petty cash replenishment"] = "Tables";
		$connectionsIds["Employee Advance Release"] = "Tables";
		$connectionsIds["Employee Advance Replenishment"] = "Tables";
		$connectionsIds["Liquidation Release"] = "Tables";
		$connectionsIds["Liquidation Replenishment"] = "Tables";
		$connectionsIds["Billable Cost Report"] = "Tables";
		$connectionsIds["centerrep_pettycash"] = "Tables";
		$connectionsIds["centerrep_empadvance"] = "Tables";
		$connectionsIds["centerrep_liquidation"] = "Tables";
		$connectionsIds["replenishment_pettycash"] = "Tables";
		$connectionsIds["replenishment_liquidation"] = "Tables";
		$connectionsIds["replenishment_empadv"] = "Tables";
		$connectionsIds["bank_statement"] = "Tables";
		$connectionsIds["other_charges"] = "Tables";
		$connectionsIds["change_password"] = "Tables";
		$connectionsIds["project_liquidation_detail2"] = "Tables";
		$connectionsIds["balance_advance"] = "Tables";
		$connectionsIds["project_replenishment_deposited"] = "Tables";
		$connectionsIds["bal_center_replenishment"] = "Tables";
		$connectionsIds["Project and Pettycash Report"] = "Tables";
		$connectionsIds["Project and EmpAdv Report"] = "Tables";
		$connectionsIds["Project and Liquidation Report"] = "Tables";
		$connectionsIds["Project and Sales Report"] = "Tables";
		$connectionsIds["Project and Voucher Report"] = "Tables";
		$connectionsIds["projects_view"] = "Tables";
		$connectionsIds["projects_lite"] = "Tables";
		$connectionsIds["shipping_date"] = "Tables";
		$connectionsIds["entry_detail_sales"] = "Tables";
		$connectionsIds["entry_detail_pettycash"] = "Tables";
		$connectionsIds["entry_detail_cash_disbursement"] = "Tables";
		$connectionsIds["representative"] = "Tables";
		$connectionsIds["sales_sub_invoice"] = "Tables";
		$connectionsIds["search_cash_disbursement"] = "Tables";
		$connectionsIds["sales_business_partner"] = "Tables";
		$connectionsIds["canvas"] = "Tables";
		$connectionsIds["canvas_detail"] = "Tables";
		$connectionsIds["request_for_payment"] = "Tables";
		$connectionsIds["request_for_payment_detail"] = "Tables";
		$connectionsIds["po_netpr"] = "Tables";
		$connectionsIds["request_for_payment_imp"] = "Tables";
		$connectionsIds["birsalesrelief"] = "Tables";
		$this->_tablesConnectionIds = $connectionsIds;
	}
	
	/**
	 * Check if It's possible to add to one table's sql query 
	 * an sql subquery to another table.
	 * Access doesn't support subqueries from the same table as main.
	 * @param String dataSourceTName1
	 * @param String dataSourceTName2
	 * @return Boolean
	 */
	public function checkTablesSubqueriesSupport( $dataSourceTName1, $dataSourceTName2 )
	{
		$connId1 = $this->_tablesConnectionIds[ $dataSourceTName1 ];
		$connId2 = $this->_tablesConnectionIds[ $dataSourceTName2 ];
		
		if( $connId1 != $connId2 )
			return false;

		if( $this->_connectionsData[ $connId1 ]["dbType"] == nDATABASE_Access && $dataSourceTName1 == $dataSourceTName2 )
			return false;
			
		return true;	
	}
	
	/**
	 * Close db connections
	 * @destructor
	 */
	function __desctruct() 
	{
		foreach( $this->cache as $connection )
		{
			$connection->close();
		}
	}
}
?>